==> flink-1.12.7-src.tgz: flink-1.12.7/flink-runtime/src/test/java/org/apache/flink/runtime/jobmanager/StandaloneJobGraphStoreTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.jobmanager;

import org.apache.flink.api.common.JobID;
import org.apache.flink.runtime.jobgraph.JobGraph;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

public class StandaloneJobGraphStoreTest {

    /** Tests that all operations work and don't change the state. */
    @Test
    public void testNoOps() {
        StandaloneJobGraphStore jobGraphs = new StandaloneJobGraphStore();

        JobGraph jobGraph = new JobGraph("testNoOps");

        assertEquals(0, jobGraphs.getJobIds().size());

        jobGraphs.putJobGraph(jobGraph);
        assertEquals(0, jobGraphs.getJobIds().size());

        jobGraphs.removeJobGraph(jobGraph.getJobID());
        assertEquals(0, jobGraphs.getJobIds().size());

        assertNull(jobGraphs.recoverJobGraph(new JobID()));
    }
}

==> flink-1.13.6-src.tgz: flink-1.13.6/flink-runtime/src/test/java/org/apache/flink/runtime/jobmanager/StandaloneJobGraphStoreTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.jobmanager;

import org.apache.flink.api.common.JobID;
import org.apache.flink.runtime.jobgraph.JobGraph;
import org.apache.flink.runtime.jobgraph.JobGraphTestUtils;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

public class StandaloneJobGraphStoreTest {

    /** Tests that all operations work and don't change the state. */
    @Test
    public void testNoOps() {
        StandaloneJobGraphStore jobGraphs = new StandaloneJobGraphStore();

        JobGraph jobGraph = JobGraphTestUtils.emptyJobGraph();

        assertEquals(0, jobGraphs.getJobIds().size());

        jobGraphs.putJobGraph(jobGraph);
        assertEquals(0, jobGraphs.getJobIds().size());

        jobGraphs.removeJobGraph(jobGraph.getJobID());
        assertEquals(0, jobGraphs.getJobIds().size());

        assertNull(jobGraphs.recoverJobGraph(new JobID()));
    }
}
